pub trait TcpAdoptStd: TcpConnect {
// Required method
fn adopt(&self, std: TcpStream) -> Result<Self::Stream>;
}Expand description
On platforms with file descriptors, the whole set of socket options is applied outside the runtime, and the runtime only adopts the finished socket.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".